@@ -18,8 +18,8 @@ class CTM(object):
 
     def __init__(self, input_size, bert_input_size, inference_type="zeroshot", num_topics=10, model_type='prodLDA',
                  hidden_sizes=(100, 100), activation='softplus', dropout=0.2, learn_priors=True, batch_size=64,
-                 lr=2e-3, momentum=0.99, solver='adam', num_epochs=100, reduce_on_plateau=False, topic_prior_mean=0.0,
-                 topic_prior_variance=None, num_data_loader_workers=0):
+                 lr=2e-3, momentum=0.99, solver='adam', num_epochs=100, num_samples=10,
+                 reduce_on_plateau=False, topic_prior_mean=0.0, topic_prior_variance=None, num_data_loader_workers=0):
         """
         :param input_size: int, dimension of input
         :param bert_input_size: int, dimension of input that comes from BERT embeddings
@@ -27,13 +27,15 @@ class CTM(object):
         :param num_topics: int, number of topic components, (default 10)
         :param model_type: string, 'prodLDA' or 'LDA' (default 'prodLDA')
         :param hidden_sizes: tuple, length = n_layers, (default (100, 100))
-        :param activation: string, 'softplus', 'relu', (default 'softplus')
+        :param activation: string, 'softplus', 'relu', 'sigmoid', 'swish', 'tanh', 'leakyrelu', 'rrelu', 'elu',
+         'selu' (default 'softplus')
         :param dropout: float, dropout to use (default 0.2)
         :param learn_priors: bool, make priors a learnable parameter (default True)
         :param batch_size: int, size of batch to use for training (default 64)
         :param lr: float, learning rate to use for training (default 2e-3)
         :param momentum: float, momentum to use for training (default 0.99)
         :param solver: string, optimizer 'adam' or 'sgd' (default 'adam')
+        :param num_samples: int, number of times theta needs to be sampled
         :param num_epochs: int, number of epochs to train for, (default 100)
         :param reduce_on_plateau: bool, reduce learning rate by 10x on plateau of 10 epochs (default False)
         :param num_data_loader_workers: int, number of data loader workers (default cpu_count). set it to 0 if you are using Windows
@@ -77,6 +79,7 @@ class CTM(object):
         self.learn_priors = learn_priors
         self.batch_size = batch_size
         self.lr = lr
+        self.num_samples = num_samples
         self.bert_size = bert_input_size
         self.momentum = momentum
         self.solver = solver
@@ -89,7 +92,7 @@ class CTM(object):
         self.model = DecoderNetwork(
             input_size, self.bert_size, inference_type, num_topics, model_type, hidden_sizes, activation,
             dropout, self.learn_priors, self.topic_prior_mean, self.topic_prior_variance)
-        self.early_stopping = EarlyStopping(patience=5, verbose=True)
+        self.early_stopping = EarlyStopping(patience=5, verbose=False)
         # init optimizer
         if self.solver == 'adam':
             self.optimizer = optim.Adam(self.model.parameters(), lr=lr, betas=(self.momentum, 0.99))
@@ -279,17 +282,18 @@ class CTM(object):
             val_samples_processed, val_loss = self._validation(validation_loader)
             e = datetime.datetime.now()
 
-            # report
-            print("Epoch: [{}/{}]\tSamples: [{}/{}]\tValidation Loss: {}\tTime: {}".format(
-                epoch + 1, self.num_epochs, val_samples_processed,
-                len(self.validation_data) * self.num_epochs, val_loss, e - s))
+            if verbose:
+                print("Epoch: [{}/{}]\tSamples: [{}/{}]\tValidation Loss: {}\tTime: {}".format(
+                    epoch + 1, self.num_epochs, val_samples_processed,
+                    len(self.validation_data) * self.num_epochs, val_loss, e - s))
 
             if np.isnan(val_loss) or np.isnan(train_loss):
                 break
             else:
                 self.early_stopping(val_loss, self.model)
                 if self.early_stopping.early_stop:
-                    print("Early stopping")
+                    if verbose:
+                        print("Early stopping")
                     if save_dir is not None:
                         self.save(save_dir)
                     break
@@ -408,22 +412,30 @@ class CTM(object):
         self.model.load_state_dict(checkpoint['state_dict'])
 
     def get_thetas(self, dataset):
-        """Predict input."""
+        """
+        Get the document-topic distribution for a dataset of topics. Includes multiple sampling to reduce variation via
+        the parameter num_samples.
+        :param dataset: a PyTorch Dataset containing the documents
+        """
         self.model.eval()
-        loader = DataLoader(dataset, batch_size=self.batch_size, shuffle=False,
-                            num_workers=self.num_data_loader_workers)
-        with torch.no_grad():
-            collect_theta = []
-            for batch_samples in loader:
-                # batch_size x vocab_size
-                X = batch_samples['X']
-                X = X.reshape(X.shape[0], -1)
-                X_bert = batch_samples['X_bert']
-                if self.USE_CUDA:
-                    X = X.cuda()
-                    X_bert = X_bert.cuda()
 
-                # forward pass
-                self.model.zero_grad()
-                collect_theta.extend(self.model.get_theta(X, X_bert).cpu().numpy().tolist())
-            return collect_theta
+        loader = DataLoader(
+            dataset, batch_size=self.batch_size, shuffle=False, num_workers=self.num_data_loader_workers)
+        final_thetas = []
+        for sample_index in range(self.num_samples):
+            with torch.no_grad():
+                collect_theta = []
+                for batch_samples in loader:
+                    # batch_size x vocab_size
+                    x = batch_samples['X']
+                    x = x.reshape(x.shape[0], -1)
+                    x_bert = batch_samples['X_bert']
+                    if self.USE_CUDA:
+                        x = x.cuda()
+                        x_bert = x_bert.cuda()
+                    # forward pass
+                    self.model.zero_grad()
+                    collect_theta.extend(self.model.get_theta(x, x_bert).cpu().numpy().tolist())
+
+                final_thetas.append(np.array(collect_theta))
+        return np.sum(final_thetas, axis=0) / self.num_samples
